@@ -22,10 +22,9 @@ class Tile:
             r"(?P<orbit>R(\d{3}))_"
             r"(?P<name>[A-Z0-9]{6})_"
             r"(?P<stop>\d{8}T(\d{6}))"
-            r"\.SAFE$"
         )
 
-        match = re.match(pattern, self.path.name, re.IGNORECASE)
+        match = re.match(pattern, self.path.with_suffix('').name, re.IGNORECASE)
 
         if not match:
             raise RuntimeError("unable to parse tile name")
@@ -52,3 +51,29 @@ class Tile:
         res = BandResolution[type(band)]
         tif = next(self.path.glob(f"GRANULE/*/IMG_DATA/R{res}m/*_{band.name}_{res}m.jp2"))
         return tif
+
+    
+    # Get the MGRS parts
+    # https://en.wikipedia.org/wiki/Military_Grid_Reference_System
+
+    def get_MGRS_GDZ(self):
+        return self.name[1:len(self.name)-2]
+
+    def get_MGRS_square_ID(self):
+        return self.name[-2:]
+
+    def get_MGRS_UTM_zone(self): 
+        utm_zone = [int(s) for s in re.findall(r'-?\d+\.?\d*', self.name)]
+        assert(len(utm_zone) == 1)
+        return utm_zone[0]
+
+    def get_MGRS_latitude_band(self): 
+        return self.name[-3:-2]
+
+    def get_MGRS_square_column(self): 
+        return self.name[-2:-1]
+
+    def get_MGRS_square_row(self): 
+        return self.name[-1:]
+
+
