@@ -1,4 +1,4 @@
-from sentile.s2 import Tile, SCL
+from sentile.s2 import Tile
 
 
 def main(args):
